@@ -345,7 +345,7 @@ static int grib_concept_apply(grib_accessor* a, const char* name)
     grib_action* act             = a->creator;
     int nofail                   = action_concept_get_nofail(a);
 
-    Assert(concepts != NULL);
+    DebugAssert(concepts);
 
     c = (grib_concept_value*)grib_trie_get(concepts->index, name);
 
@@ -356,14 +356,14 @@ static int grib_concept_apply(grib_accessor* a, const char* name)
         err = nofail ? GRIB_SUCCESS : GRIB_CONCEPT_NO_MATCH;
         if (err) {
             size_t i = 0, concept_count = 0;
-            long dummy = 0, editionNumber                  = 0;
+            long dummy = 0, editionNumber = 0;
             char* all_concept_vals[MAX_NUM_CONCEPT_VALUES] = {
                 NULL,
             }; /* sorted array containing concept values */
             grib_concept_value* pCon = concepts;
 
             grib_context_log(h->context, GRIB_LOG_ERROR, "concept: no match for %s=%s", act->name, name);
-            if (strcmp(act->name, "paramId")==0 && string_to_long(name, &dummy)==GRIB_SUCCESS) {
+            if (strcmp(act->name, "paramId") == 0 && string_to_long(name, &dummy) == GRIB_SUCCESS) {
                 grib_context_log(h->context, GRIB_LOG_ERROR,
                                  "Please check the Parameter Database 'https://apps.ecmwf.int/codes/grib/param-db/?id=%s'", name);
             }
@@ -441,11 +441,12 @@ static int unpack_double(grib_accessor* a, double* val, size_t* len)
     int ret = 0;
     if (a->flags & GRIB_ACCESSOR_FLAG_LONG_TYPE) {
         long lval = 0;
-        ret = unpack_long(a, &lval, len);
+        ret       = unpack_long(a, &lval, len);
         if (ret == GRIB_SUCCESS) {
             *val = lval;
         }
-    } else if (a->flags & GRIB_ACCESSOR_FLAG_DOUBLE_TYPE) {
+    }
+    else if (a->flags & GRIB_ACCESSOR_FLAG_DOUBLE_TYPE) {
         const char* p = concept_evaluate(a);
 
         if (!p) {
@@ -559,6 +560,7 @@ static void destroy(grib_context* c, grib_accessor* a)
      */
 }
 
+#if 0
 static int is_local_ecmwf_grib2_param_key(grib_accessor* a, long edition, long centre)
 {
     if (edition == 2 && centre == 98) {
@@ -567,44 +569,9 @@ static int is_local_ecmwf_grib2_param_key(grib_accessor* a, long edition, long c
     }
     return 0;
 }
+#endif
 
-static char* get_legacy_param_info(const char* key_name, long paramId)
-{
-    if (paramId == 210) {
-        if (strcmp(key_name, "paramId") == 0)
-            return "210";
-        if (strcmp(key_name, "shortName") == 0)
-            return "ssrc";
-        if (strcmp(key_name, "units") == 0)
-            return "J m**-2";
-        if (strcmp(key_name, "name") == 0)
-            return "Surface net solar radiation, clear sky";
-        if (strcmp(key_name, "cfVarName") == 0)
-            return "ssrc";
-        if (strcmp(key_name, "cfName") == 0)
-            return "surface_net_downward_shortwave_flux_assuming_clear_sky";
-    }
-    else if (paramId == 211) {
-        if (strcmp(key_name, "paramId") == 0)
-            return "211";
-        if (strcmp(key_name, "shortName") == 0)
-            return "strc";
-        if (strcmp(key_name, "units") == 0)
-            return "J m**-2";
-        if (strcmp(key_name, "name") == 0)
-            return "Surface net thermal radiation, clear sky";
-        if (strcmp(key_name, "cfVarName") == 0)
-            return "strc";
-        if (strcmp(key_name, "cfName") == 0)
-            return "surface_net_downward_longwave_flux_assuming_clear_sky";
-    }
-    else if (paramId == 228051 || paramId == 228053 || paramId == 228057 || paramId == 228058 || paramId == 228059 || paramId == 228060) {
-        if (strcmp(key_name, "cfName") == 0)
-            return "unknown";
-    }
-    return NULL;
-}
-
+#if 0
 /* Try to get the name, shortName, units etc for a GRIB2 message with
  * local ECMWF coding i.e. discipline=192 etc
  */
@@ -622,18 +589,12 @@ static const char* get_ECMWF_local_parameter(grib_accessor* a, grib_handle* h)
     if (err)
         return NULL;
     if (is_local_ecmwf_grib2_param_key(a, edition, centre)) {
-        char* pLocalParam = NULL;
         /* Must be one of: 'name', 'shortName', 'units', 'cfName' etc */
         grib_accessor* a2    = NULL;
         const long pid_guess = guess_paramId(h);
         if (pid_guess == -1)
             return NULL;
 
-        /* TODO: Need to revisit */
-        pLocalParam = get_legacy_param_info(key_name, pid_guess);
-        if (pLocalParam)
-            return pLocalParam;
-
         /* Change the paramId so we can get the other string key*/
         err = grib_set_long(h, "paramId", pid_guess);
         if (err)
@@ -648,6 +609,8 @@ static const char* get_ECMWF_local_parameter(grib_accessor* a, grib_handle* h)
     }
     return NULL;
 }
+#endif
+
 static int unpack_string(grib_accessor* a, char* val, size_t* len)
 {
     size_t slen;
@@ -655,23 +618,19 @@ static int unpack_string(grib_accessor* a, char* val, size_t* len)
 
     if (!p) {
         grib_handle* h = grib_handle_of_accessor(a);
-        p              = get_ECMWF_local_parameter(a, h);
-        if (!p) {
-            if (a->creator->defaultkey)
-                return grib_get_string_internal(h, a->creator->defaultkey, val, len);
+        if (a->creator->defaultkey)
+            return grib_get_string_internal(h, a->creator->defaultkey, val, len);
 
-            return GRIB_NOT_FOUND;
-        }
-        grib_context_log(h->context, GRIB_LOG_DEBUG, "ECMWF local grib2 parameter: %s=%s", a->name, p);
+        return GRIB_NOT_FOUND;
     }
 
     slen = strlen(p) + 1;
     if (*len < slen) {
-        grib_context_log(a->context, GRIB_LOG_ERROR, "Variable unpack_string Wrong size for %s it is %d bytes big (len=%d)", a->name, slen, *len);
+        grib_context_log(a->context, GRIB_LOG_ERROR, "Variable unpack_string. Wrong size for %s, it is %d bytes big (len=%d)", a->name, slen, *len);
         *len = slen;
         return GRIB_BUFFER_TOO_SMALL;
     }
-    strcpy(val, p);
+    strcpy(val, p); /* NOLINT: CWE-119 clang-analyzer-security.insecureAPI.strcpy */
     *len = slen;
 #if 0
     if (a->context->debug==1) {
